@@ -26,6 +26,34 @@ class RedisClient(AbstractClient):
     _service = 'redis'
 
 
+    def AddReplicationInstance(self, request):
+        """添加复制组成员
+
+        :param request: Request instance for AddReplicationInstance.
+        :type request: :class:`tencentcloud.redis.v20180412.models.AddReplicationInstanceRequest`
+        :rtype: :class:`tencentcloud.redis.v20180412.models.AddReplicationInstanceResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("AddReplicationInstance", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.AddReplicationInstanceResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def ApplyParamsTemplate(self, request):
         """应用参数模板到实例
 
@@ -223,7 +251,7 @@ class RedisClient(AbstractClient):
 
 
     def CreateParamTemplate(self, request):
-        """创建参数模板
+        """创建参数模板。
 
         :param request: Request instance for CreateParamTemplate.
         :type request: :class:`tencentcloud.redis.v20180412.models.CreateParamTemplateRequest`
@@ -250,6 +278,34 @@ class RedisClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def CreateReplicationGroup(self, request):
+        """创建复制组
+
+        :param request: Request instance for CreateReplicationGroup.
+        :type request: :class:`tencentcloud.redis.v20180412.models.CreateReplicationGroupRequest`
+        :rtype: :class:`tencentcloud.redis.v20180412.models.CreateReplicationGroupResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("CreateReplicationGroup", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.CreateReplicationGroupResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DeleteInstanceAccount(self, request):
         """删除实例子账号
 
@@ -306,6 +362,34 @@ class RedisClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DeleteReplicationInstance(self, request):
+        """移除复制组成员
+
+        :param request: Request instance for DeleteReplicationInstance.
+        :type request: :class:`tencentcloud.redis.v20180412.models.DeleteReplicationInstanceRequest`
+        :rtype: :class:`tencentcloud.redis.v20180412.models.DeleteReplicationInstanceResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DeleteReplicationInstance", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DeleteReplicationInstanceResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeAutoBackupConfig(self, request):
         """获取备份配置
 
@@ -1146,6 +1230,34 @@ class RedisClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeReplicationGroup(self, request):
+        """查询复制组
+
+        :param request: Request instance for DescribeReplicationGroup.
+        :type request: :class:`tencentcloud.redis.v20180412.models.DescribeReplicationGroupRequest`
+        :rtype: :class:`tencentcloud.redis.v20180412.models.DescribeReplicationGroupResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeReplicationGroup", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeReplicationGroupResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeSlowLog(self, request):
         """查询实例慢查询记录
 
@@ -1567,7 +1679,7 @@ class RedisClient(AbstractClient):
 
 
     def ModifyAutoBackupConfig(self, request):
-        """设置自动备份时间
+        """设置自动备份配置
 
         :param request: Request instance for ModifyAutoBackupConfig.
         :type request: :class:`tencentcloud.redis.v20180412.models.ModifyAutoBackupConfigRequest`
